
# Update Collection

## Collection Name 



## Description
Angle rotation of the left leg from vertical

## Qualified Name
DataField::AngleLeftField

## Classifications


## Collection Type


## Guid
8aa5bef9-3a20-4160-a579-6e63b4db7f67




# Update Collection

## Collection Name 



## Description
Unique identifier of the patient

## Qualified Name
DataField::PatientId

## Classifications


## Collection Type


## Guid
a698b362-a781-41c6-9e6e-bde6fe3a1737



## In Data Dictionary

None


# Provenance

* Results from processing file data_field.md on 2025-05-17 16:01
